@@ -20,7 +20,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #include <math.h>
@@ -117,12 +117,9 @@ static FSNodeRep *shared = nil;
     NSNotificationCenter *nc;
     
     fm = [NSFileManager defaultManager];
-    ws = [NSWorkspace sharedWorkspace];
     nc = [NSNotificationCenter defaultCenter];
           
     labelWFactor = LABEL_W_FACT;
-    
-    oldresize = [[NSUserDefaults standardUserDefaults] boolForKey: @"old_resize"];
 
     /* images coming form GSTheme */
     [self cacheIcons];
@@ -165,12 +162,10 @@ static FSNodeRep *shared = nil;
     lockedPaths = [NSMutableArray new];	
     hiddenPaths = [NSArray new];
     volumes = [[NSMutableSet alloc] initWithCapacity: 1];
-    [self setVolumes:[ws mountedRemovableMedia]];
+    [self setVolumes:[[NSWorkspace sharedWorkspace] mountedRemovableMedia]];
     reservedNames = [[NSMutableSet alloc] initWithCapacity: 1];
     
     [self loadExtendedInfoModules];
-    
-    systype = [[NSProcessInfo processInfo] operatingSystem];
 
     /* we observe a theme change to re-cache icons */
     [nc addObserver:self selector:@selector(themeDidActivate:) name:GSThemeDidActivateNotification object:nil];
@@ -292,9 +287,10 @@ static FSNodeRep *shared = nil;
 
 + (FSNodeRep *)sharedInstance
 {
-	if (shared == nil) {
-		shared = [[FSNodeRep alloc] initSharedInstance];
-	}	
+  if (shared == nil)
+    {
+      shared = [[FSNodeRep alloc] initSharedInstance];
+    }
   return shared;
 }
 
@@ -474,58 +470,66 @@ static FSNodeRep *shared = nil;
 {
   NSString *path = [node path];
     
-	if ([lockedPaths containsObject: path] == NO) {
-		[lockedPaths addObject: path];
-	} 
+  if ([lockedPaths containsObject: path] == NO)
+    {
+      [lockedPaths addObject: path];
+    }
 }
 
 - (void)lockPath:(NSString *)path
 {
-	if ([lockedPaths containsObject: path] == NO) {
-		[lockedPaths addObject: path];
-	} 
+  if ([lockedPaths containsObject: path] == NO)
+    {
+      [lockedPaths addObject: path];
+    }
 }
 
 - (void)lockNodes:(NSArray *)nodes
 {
   NSUInteger i;
 	  
-	for (i = 0; i < [nodes count]; i++) {
-    NSString *path = [[nodes objectAtIndex: i] path];
+  for (i = 0; i < [nodes count]; i++)
+    {
+      NSString *path = [[nodes objectAtIndex: i] path];
     
-		if ([lockedPaths containsObject: path] == NO) {
-			[lockedPaths addObject: path];
-		} 
+      if ([lockedPaths containsObject: path] == NO)
+	{
+	  [lockedPaths addObject: path];
 	}
+    }
 }
 
 - (void)lockPaths:(NSArray *)paths
 {
-	int i;
+  NSUInteger i;
 	  
-	for (i = 0; i < [paths count]; i++) {
-    NSString *path = [paths objectAtIndex: i];
+  for (i = 0; i < [paths count]; i++)
+    {
+      NSString *path = [paths objectAtIndex: i];
     
-		if ([lockedPaths containsObject: path] == NO) {
-			[lockedPaths addObject: path];
-		} 
+      if ([lockedPaths containsObject: path] == NO)
+	{
+	  [lockedPaths addObject: path];
 	}
+    }
 }
 
 - (void)unlockNode:(FSNode *)node
 {
   NSString *path = [node path];
 
-	if ([lockedPaths containsObject: path]) {
-		[lockedPaths removeObject: path];
-	} 
+  if ([lockedPaths containsObject: path])
+    {
+      [lockedPaths removeObject: path];
+    }
 }
 
 - (void)unlockPath:(NSString *)path
 {
-	if ([lockedPaths containsObject: path]) {
-		[lockedPaths removeObject: path];
-	} 
+  if ([lockedPaths containsObject: path])
+    {
+      [lockedPaths removeObject: path];
+    }
 }
 
 - (void)unlockNodes:(NSArray *)nodes
@@ -536,9 +540,10 @@ static FSNodeRep *shared = nil;
     {
       NSString *path = [[nodes objectAtIndex: i] path];
 	
-		if ([lockedPaths containsObject: path]) {
-			[lockedPaths removeObject: path];
-		} 
+      if ([lockedPaths containsObject: path])
+	{
+	  [lockedPaths removeObject: path];
+	}
     }
 }
 
@@ -632,10 +637,6 @@ static FSNodeRep *shared = nil;
   return [reservedNames containsObject: name];
 }
 
-- (unsigned)systemType
-{
-  return systype;
-}
 
 - (void)setUseThumbnails:(BOOL)value
 {
