@@ -19,43 +19,19 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 
 #import <Foundation/Foundation.h>
+#import "ExecuteController.h"
+
 
-@class CompletionField;
-@class NSBox;
-@class NSWindow;
 @class GWorkspace;
 
-@interface OpenWithController : NSObject 
+@interface OpenWithController : ExecuteController
 {
-  IBOutlet id win;
-  IBOutlet id firstLabel;
-  IBOutlet id secondLabel;
-  IBOutlet id cancelButt;
-  IBOutlet id okButt;
-
-  IBOutlet CompletionField *cfield;
-  unsigned result;  
-  
-  NSArray *pathsArr;
-  NSFileManager *fm;
   GWorkspace *gw;  
 }
 
-- (NSString *)checkCommand:(NSString *)comm;
-
-- (void)activate;
-
-- (NSWindow *)win;
-
-- (IBAction)cancelButtAction:(id)sender;
-
-- (IBAction)okButtAction:(id)sender;
-
-- (void)completionFieldDidEndLine:(id)afield;
-
 @end
