@@ -19,7 +19,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 
@@ -27,38 +27,15 @@
 #define RUN_EXTERNAL_CONTROLLER_H
 
 #import <Foundation/Foundation.h>
+#import "ExecuteController.h"
 
-@class CompletionField;
 @class NSTextField;
 @class NSWindow;
 
-@interface RunExternalController : NSObject 
+@interface RunExternalController : ExecuteController
 {
-  IBOutlet NSWindow *win;
-  IBOutlet NSTextField *titleLabel;
-  IBOutlet NSTextField *secondLabel;
-  IBOutlet NSButton *cancelButt;
-  IBOutlet NSButton *okButt;
-  
-  IBOutlet CompletionField *cfield;
-  unsigned result;  
-  
-  NSArray *pathsArr;
-  NSFileManager *fm;
-  
 }
 
-- (NSString *)checkCommand:(NSString *)comm;
-
-- (void)activate;
-
-- (NSWindow *)win;
-
-- (IBAction)cancelButtAction:(id)sender;
-
-- (IBAction)okButtAction:(id)sender;
-
-- (void)completionFieldDidEndLine:(id)afield;
 
 @end
 
