@@ -1,9 +1,9 @@
 /* GWViewerIconsPath.m
  *  
- * Copyright (C) 2004-2016 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2022 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
- *         Riccardo Mottola <rm@gnu.org>
+ * Authors: Enrico Sersale <enrico@imago.ro>
+ *          Riccardo Mottola <rm@gnu.org>
  * Date: July 2004
  *
  * This file is part of the GNUstep GWorkspace application
@@ -20,7 +20,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #include <math.h>
@@ -700,10 +700,8 @@
 
     [nameEditor setFrame: edrect];
     [nameEditor setAlignment: NSCenterTextAlignment];
-
     [nameEditor setNode: ednode 
-            stringValue: nodeDescr
-                  index: 0];
+            stringValue: nodeDescr];
 
     [nameEditor setBackgroundColor: [NSColor selectedControlColor]];
 
@@ -727,7 +725,7 @@
     [nameEditor abortEditing];
     [nameEditor setEditable: NO];
     [nameEditor setSelectable: NO];
-    [nameEditor setNode: nil stringValue: @"" index: -1];
+    [nameEditor setNode: nil stringValue: @""];
     [nameEditor removeFromSuperview];
     [self setNeedsDisplayInRect: edrect];
   }
