@@ -19,7 +19,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #import <AppKit/AppKit.h>
@@ -303,15 +303,17 @@ static GWViewersManager *vwrsmanager = nil;
 
 - (id)rootViewer
 {
-  int i;
+  NSUInteger i;
 
-  for (i = 0; i < [viewers count]; i++) {
-    id viewer = [viewers objectAtIndex: i];
+  for (i = 0; i < [viewers count]; i++)
+    {
+      id viewer = [viewers objectAtIndex: i];
 
-    if ([viewer isFirstRootViewer]) {
-      return viewer;
+      if ([viewer isFirstRootViewer])
+	{
+	  return viewer;
+	}
     }
-  }
 
   return nil;
 }
@@ -517,11 +519,12 @@ static GWViewersManager *vwrsmanager = nil;
 - (void)sortTypeDidChange:(NSNotification *)notif
 {
   NSString *notifPath = [notif object];
-  int i;
+  NSUInteger i;
 
-  for (i = 0; i < [viewers count]; i++) {
-    [[[viewers objectAtIndex: i] nodeView] sortTypeChangedAtPath: notifPath];
-  }  
+  for (i = 0; i < [viewers count]; i++)
+    {
+      [[[viewers objectAtIndex: i] nodeView] sortTypeChangedAtPath: notifPath];
+    }
 }
 
 - (void)fileSystemWillChange:(NSNotification *)notif
