@@ -1,8 +1,10 @@
 /* Annotations.h
  *  
- * Copyright (C) 2005-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2024 Free Software Foundation, Inc.
+ *
+ * Authors: Enrico Sersale
+ *          Riccardo Mottola
  *
- * Author: Enrico Sersale <enrico@imago.ro>
  * Date: February 2005
  *
  * This file is part of the GNUstep GWorkspace application
@@ -19,25 +21,28 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 
 #import <Foundation/Foundation.h>
 
+@class NSWindow;
 @class FSNode;
 @class NSView;
+@class IconView;
+@class NSTextView;
 
 @interface Annotations: NSObject
 {
-  IBOutlet id win;
+  IBOutlet NSWindow *win;
   IBOutlet NSBox *mainBox;
   IBOutlet NSBox *topBox;
-  IBOutlet id iconView;
-  IBOutlet id titleField;
+  IBOutlet IconView *iconView;
+  IBOutlet NSTextField *titleField;
   IBOutlet NSBox *toolsBox;
-  IBOutlet id textView;
-  IBOutlet id okButt;
+  IBOutlet NSTextView *textView;
+  IBOutlet NSButton *okButt;
 
   NSString *currentPath;
   NSView *noContsView; 
@@ -45,7 +50,7 @@
   id desktopApp;
 }
 
-- (id)initForInspector:(id)insp;
+- (instancetype)initForInspector:(id)insp;
 
 - (NSView *)inspView;
 
