@@ -19,7 +19,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #include <AppKit/AppKit.h>
@@ -136,10 +136,6 @@
 {
 }
 
-- (void)displayLastPath:(BOOL)forced
-{
-}
-
 - (void)displayData:(NSData *)data 
              ofType:(NSString *)type
 {
@@ -214,7 +210,7 @@
   }  
 }
 
-- (NSString *)currentPath
+- (NSString *)path
 {
   return nil;
 }
