@@ -20,7 +20,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #ifndef IMAGEVIEWER_H
@@ -67,14 +67,13 @@
   NSButton *editButt;
   
   NSString *imagePath;
-  NSString *nextPath;
   NSString *editPath;
   
   NSConnection *conn;  
   ImageResizer *resizer;
   
   id <ContentInspectorProtocol>inspector;
-  NSFileManager *fm;
+
   NSWorkspace *ws;
 }
 
