@@ -1,6 +1,6 @@
 /* ImageViewer.m
  *  
- * Copyright (C) 2004-2021 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2024 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  *         Riccardo Mottola <rm@gnu.org>
@@ -20,7 +20,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #import <AppKit/AppKit.h>
@@ -33,12 +33,10 @@
 
 - (void)dealloc
 {
-  DESTROY (resizer);    
-  RELEASE (imagePath);	
-  RELEASE (image);	
-  RELEASE (nextPath);	
-  RELEASE (editPath);	
-  RELEASE (extsarr);
+  DESTROY (resizer);
+  RELEASE (imagePath);
+  RELEASE (image);
+  RELEASE (editPath);
   RELEASE (imview);
   RELEASE (errLabel);
   RELEASE (progView);
@@ -62,7 +60,7 @@
     [imview setImageFrameStyle: NSImageFrameGrayBezel];
     [imview setImageAlignment: NSImageAlignCenter];
     [imview setImageScaling: NSScaleNone];
-    [self addSubview: imview]; 
+    [self addSubview: imview];
     
     r.origin.x = 10;
     r.origin.y -= 20;
@@ -85,7 +83,7 @@
     [heightLabel setSelectable: NO];
     [heightLabel setAlignment: NSRightTextAlignment];
     [heightLabel setStringValue: @""];
-    [self addSubview: heightLabel]; 
+    [self addSubview: heightLabel];
     RELEASE (heightLabel);
 
     r.origin.x = 2;
@@ -112,36 +110,31 @@
     r.origin.y = 10;
     r.size.width = 115;
     r.size.height = 25;
-	  editButt = [[NSButton alloc] initWithFrame: r];
-	  [editButt setButtonType: NSMomentaryLight];
+    editButt = [[NSButton alloc] initWithFrame: r];
+    [editButt setButtonType: NSMomentaryLight];
     [editButt setImage: [NSImage imageNamed: @"common_ret.tiff"]];
     [editButt setImagePosition: NSImageRight];
-	  [editButt setTitle: NSLocalizedString(@"Edit", @"")];
-	  [editButt setTarget: self];
-	  [editButt setAction: @selector(editFile:)];	
-    [editButt setEnabled: NO];		
-		[self addSubview: editButt]; 
+    [editButt setTitle: NSLocalizedString(@"Edit", @"")];
+    [editButt setTarget: self];
+    [editButt setAction: @selector(editFile:)];
+    [editButt setEnabled: NO];
+    [self addSubview: editButt];
     RELEASE (editButt);
 
-    ASSIGN (extsarr, ([NSArray arrayWithObjects: @"tiff", @"tif", @"png", 
-                                            @"jpeg", @"jpg", @"gif", nil]));
-
     inspector = insp;
-    fm = [NSFileManager defaultManager];
     ws = [NSWorkspace sharedWorkspace];
-        
+
     valid = YES;
-    
+
     resizer = nil;
     imagePath = nil;
-    nextPath = nil;
     editPath = nil;
     image = nil;
-    
+
     [self setContextHelp];
   }
 	
-	return self;
+  return self;
 }
 
 - (void)displayPath:(NSString *)path
@@ -151,14 +144,7 @@
   [widthLabel setStringValue: @""];
   [heightLabel setStringValue: @""];
   
-  if (imagePath)
-    {
-      ASSIGN (nextPath, path);
-      return;
-    }
-  
   ASSIGN (imagePath, path);
-
   if (conn == nil)
     {
       NSPort *p1;
@@ -188,17 +174,6 @@
     }
 }
 
-- (void)displayLastPath:(BOOL)forced
-{
-  if (editPath) {
-    if (forced) {
-      [self displayPath: editPath];
-    } else {
-      [imview setImage: image];
-      [inspector contentsReadyAt: editPath];
-    }
-  }
-}
 
 - (oneway void)setResizer:(id)anObject
 {
@@ -221,33 +196,48 @@
 {
   NSData *imgdata;
   BOOL imgok;
-  NSString *lastPath;
 
-  if (imginfo == nil)
-    return;
-
-  imgdata = [imginfo objectForKey:@"imgdata"];
   imgok = NO;
+  imgdata = nil;
+
+  // whether we have or not read an image, we declare the content is ready
+  // at most we won't display it, otherwise other data does not update
+  if ([self superview])
+    [inspector contentsReadyAt: imagePath];
+
+  if (nil != imginfo)
+    {
+      imgdata = [imginfo objectForKey:@"imgdata"];
+
+      // since resizing is async, we check if we still need the generated image
+      if ([imagePath isEqualToString:[imginfo objectForKey: @"imgpath"]] == NO)
+	{
+	  NSLog(@"ImageViewer: trying to display inconsistent image");
+	  return;
+	}
+    }
+  else
+    {
+      NSLog(@"imageReady without imginfo");
+    }
+
   if (imgdata)
     {
-      if ([self superview])
-        [inspector contentsReadyAt: imagePath];
-      
       DESTROY (image);
       image = [[NSImage alloc] initWithData: imgdata];
 
-      imgok = YES;
       if (image)
         {
           float width = [[imginfo objectForKey: @"width"] floatValue];
           float height = [[imginfo objectForKey: @"height"] floatValue];
           NSString *str;
 
+	  imgok = YES;
           if (valid == NO)
             {
               valid = YES;
               [errLabel removeFromSuperview];
-              [self addSubview: imview]; 
+              [self addSubview: imview];
             }
 
           [imview setImage: image];
@@ -263,32 +253,26 @@
           ASSIGN (editPath, imagePath);
           [editButt setEnabled: YES];		
           [[self window] makeFirstResponder: editButt];
+	  DESTROY (imagePath);
         }
+      else
+	{
+	  NSLog(@"no image returned");
+	}
     }
 
-  
-  if (imgok == NO) {
-    if (valid == YES) {
+  if (imgok == NO)
+    {
       valid = NO;
       [imview removeFromSuperview];
       [self addSubview: errLabel];
       [widthLabel setStringValue: @""];
       [heightLabel setStringValue: @""];
-      [editButt setEnabled: NO];		
+      [editButt setEnabled: NO];
     }
-  }
-  
+
   [progView stop];
   [progView removeFromSuperview];  
-  
-  lastPath = [NSString stringWithString: imagePath];
-  DESTROY (imagePath);
-
-  if (nextPath && ([nextPath isEqual: lastPath] == NO)) {
-    NSString *next = [NSString stringWithString: nextPath];
-    DESTROY (nextPath);    
-    [self displayPath: next];
-  }
 }
 
 - (void)displayData:(NSData *)data 
@@ -296,7 +280,7 @@
 {
 }
 
-- (NSString *)currentPath
+- (NSString *)path
 {
   return editPath;
 }
@@ -309,26 +293,23 @@
 - (BOOL)canDisplayPath:(NSString *)path
 {
   NSDictionary *attributes;
-	NSString *defApp, *fileType, *extension;
+  NSString *defApp, *fileType, *extension;
 
-  attributes = [fm fileAttributesAtPath: path traverseLink: YES];
-  if ([attributes objectForKey: NSFileType] == NSFileTypeDirectory) {
-    return NO;
-  }		
+  attributes = [[NSFileManager defaultManager] fileAttributesAtPath: path traverseLink: YES];
+  if ([attributes objectForKey: NSFileType] == NSFileTypeDirectory)
+    {
+      return NO;
+    }
 		
-	[ws getInfoForFile: path application: &defApp type: &fileType];
-	extension = [path pathExtension];
-	
-  if (([fileType isEqual: NSPlainFileType] == NO)
-                  && ([fileType isEqual: NSShellCommandFileType] == NO)) {
-		return NO;
-	}
+  [ws getInfoForFile: path application: &defApp type: &fileType];
+  extension = [path pathExtension];
 
-  if ([extsarr containsObject: [extension lowercaseString]]) {
-    return YES;
-  }
+  if ([[NSImage imageFileTypes] containsObject: [extension lowercaseString]])
+    {
+      return YES;
+    }
 
-	return NO;
+  return NO;
 }
 
 - (BOOL)canDisplayDataOfType:(NSString *)type
@@ -338,12 +319,12 @@
 
 - (NSString *)winname
 {
-	return NSLocalizedString(@"Image Inspector", @"");	
+  return NSLocalizedString(@"Image Inspector", @"");
 }
 
 - (NSString *)description
 {
-	return NSLocalizedString(@"This Inspector allow you view the content of an Image file", @"");	
+  return NSLocalizedString(@"This Inspector allow you view the content of an Image file", @"");
 }
 
 - (void)editFile:(id)sender
@@ -356,11 +337,11 @@
   if (appName) {
     NS_DURING
       {
-    [ws openFile: editPath withApplication: appName];
+        [ws openFile: editPath withApplication: appName];
       }
     NS_HANDLER
       {
-    NSRunAlertPanel(NSLocalizedString(@"error", @""), 
+        NSRunAlertPanel(NSLocalizedString(@"error", @""),
         [NSString stringWithFormat: @"%@ %@!", 
           NSLocalizedString(@"Can't open ", @""), [editPath lastPathComponent]],
                                       NSLocalizedString(@"OK", @""), 
@@ -385,7 +366,7 @@
   
     helpPath = [resPath stringByAppendingPathComponent: helpPath];
   
-    if ([fm fileExistsAtPath: helpPath]) {
+    if ([[NSFileManager defaultManager] fileExistsAtPath: helpPath]) {
       NSAttributedString *help = [[NSAttributedString alloc] initWithPath: helpPath
                                                        documentAttributes: NULL];
       if (help) {
