@@ -1,8 +1,8 @@
 /* SoundViewer.m
  *  
- * Copyright (C) 2004-2011 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2025 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
+ * Author: Enrico Sersale
  * Date: January 2004
  *
  * This file is part of the GNUstep Inspector application
@@ -19,7 +19,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #import <AppKit/AppKit.h>
@@ -40,96 +40,97 @@
 - (id)initWithFrame:(NSRect)frameRect
           inspector:(id)insp
 {
-	self = [super initWithFrame: frameRect];
+  self = [super initWithFrame: frameRect];
 
-	if(self) {
-		NSBundle *bundle;
-		NSString *imagePath;
-		NSImage *image;
-		
-		playBox = [[NSBox alloc] initWithFrame: NSMakeRect(30, 125, 197, 80)];	
-    [playBox setBorderType: NSGrooveBorder];
-		[playBox setTitle: NSLocalizedString(@"Player", @"")];
-    [playBox setTitlePosition: NSAtTop];
-		[playBox setContentViewMargins: NSMakeSize(0, 0)]; 
-		[self addSubview: playBox]; 
+	if(self)
+	  {
+	    NSBundle *bundle;
+	    NSString *imagePath;
+	    NSImage *image;
 
-		bundle = [NSBundle bundleForClass: [self class]];
-		
-		stopButt = [[NSButton alloc] initWithFrame: NSMakeRect(56, 30, 24, 24)];
-		[stopButt setButtonType: NSMomentaryLight];
-		[stopButt setImagePosition: NSImageOnly];
-		imagePath = [bundle pathForResource: @"stop" ofType: @"tiff" inDirectory: nil];		
-		image = [[NSImage alloc] initWithContentsOfFile: imagePath];
-		[stopButt setImage: image];
-		RELEASE (image);
-		[stopButt setTarget:self];
-		[stopButt setAction:@selector(buttonsAction:)];
-		[playBox addSubview: stopButt]; 
-    RELEASE (pauseButt);
+	    playBox = [[NSBox alloc] initWithFrame: NSMakeRect(30, 125, 197, 80)];	
+	    [playBox setBorderType: NSGrooveBorder];
+	    [playBox setTitle: NSLocalizedString(@"Player", @"")];
+	    [playBox setTitlePosition: NSAtTop];
+	    [playBox setContentViewMargins: NSMakeSize(0, 0)]; 
+	    [self addSubview: playBox]; 
+
+	    bundle = [NSBundle bundleForClass: [self class]];
+
+	    stopButt = [[NSButton alloc] initWithFrame: NSMakeRect(56, 30, 24, 24)];
+	    [stopButt setButtonType: NSMomentaryLight];
+	    [stopButt setImagePosition: NSImageOnly];
+	    imagePath = [bundle pathForResource: @"stop" ofType: @"tiff" inDirectory: nil];
+	    image = [[NSImage alloc] initWithContentsOfFile: imagePath];
+	    [stopButt setImage: image];
+	    RELEASE (image);
+	    [stopButt setTarget:self];
+	    [stopButt setAction:@selector(buttonsAction:)];
+	    [playBox addSubview: stopButt]; 
+	    RELEASE (pauseButt);
     
-		pauseButt = [[NSButton alloc] initWithFrame: NSMakeRect(86, 30, 24, 24)];
-		[pauseButt setButtonType: NSMomentaryLight];
-		[pauseButt setImagePosition: NSImageOnly];
-		imagePath = [bundle pathForResource: @"pause" ofType: @"tiff" inDirectory: nil];		
-		image = [[NSImage alloc] initWithContentsOfFile: imagePath];
-		[pauseButt setImage: image];
-		RELEASE (image);
-		[pauseButt setTarget:self];
-		[pauseButt setAction:@selector(buttonsAction:)];
-		[playBox addSubview: pauseButt]; 
-    RELEASE (pauseButt);
+	    pauseButt = [[NSButton alloc] initWithFrame: NSMakeRect(86, 30, 24, 24)];
+	    [pauseButt setButtonType: NSMomentaryLight];
+	    [pauseButt setImagePosition: NSImageOnly];
+	    imagePath = [bundle pathForResource: @"pause" ofType: @"tiff" inDirectory: nil];
+	    image = [[NSImage alloc] initWithContentsOfFile: imagePath];
+	    [pauseButt setImage: image];
+	    RELEASE (image);
+	    [pauseButt setTarget:self];
+	    [pauseButt setAction:@selector(buttonsAction:)];
+	    [playBox addSubview: pauseButt]; 
+	    RELEASE (pauseButt);
 
-		playButt = [[NSButton alloc] initWithFrame: NSMakeRect(116, 30, 24, 24)];
-		[playButt setButtonType: NSMomentaryLight];
-		[playButt setImagePosition: NSImageOnly];
-		imagePath = [bundle pathForResource: @"play" ofType: @"tiff" inDirectory: nil];		
-		image = [[NSImage alloc] initWithContentsOfFile: imagePath];
-		[playButt setImage: image];
-		RELEASE (image);
-		[playButt setTarget:self];
-		[playButt setAction:@selector(buttonsAction:)];
-		[playBox addSubview: playButt]; 
-    RELEASE (playButt);
-		
-		indicator = [[NSProgressIndicator alloc] 
+	    playButt = [[NSButton alloc] initWithFrame: NSMakeRect(116, 30, 24, 24)];
+	    [playButt setButtonType: NSMomentaryLight];
+	    [playButt setImagePosition: NSImageOnly];
+	    imagePath = [bundle pathForResource: @"play" ofType: @"tiff" inDirectory: nil];
+	    image = [[NSImage alloc] initWithContentsOfFile: imagePath];
+	    [playButt setImage: image];
+	    RELEASE (image);
+	    [playButt setTarget:self];
+	    [playButt setAction:@selector(buttonsAction:)];
+	    [playBox addSubview: playButt]; 
+	    RELEASE (playButt);
+
+	    indicator = [[NSProgressIndicator alloc] 
 				initWithFrame: NSMakeRect(10, 6, 172, 16)];
-		[indicator setIndeterminate: YES];
-		[playBox addSubview: indicator]; 
-								
-    editButt = [[NSButton alloc] initWithFrame: NSMakeRect(141, 10, 115, 25)];
-	  [editButt setButtonType: NSMomentaryLight];
-    [editButt setImage: [NSImage imageNamed: @"common_ret.tiff"]];
-    [editButt setImagePosition: NSImageRight];
-	  [editButt setTitle: NSLocalizedString(@"Edit", @"")];
-	  [editButt setTarget: self];
-	  [editButt setAction: @selector(editFile:)];	
-    [editButt setEnabled: NO];		
-		[self addSubview: editButt]; 
-    RELEASE (editButt);
-    
-  	errLabel = [[NSTextField alloc] init];	
-		[errLabel setFrame: NSMakeRect(5, 162, [self bounds].size.width - 10, 25)];
-  	[errLabel setAlignment: NSCenterTextAlignment];
-		[errLabel setFont: [NSFont systemFontOfSize: 18]];
-  	[errLabel setBackgroundColor: [NSColor windowBackgroundColor]];
-  	[errLabel setTextColor: [NSColor darkGrayColor]];	
-  	[errLabel setBezeled: NO];
-  	[errLabel setEditable: NO];
-  	[errLabel setSelectable: NO];
-		[errLabel setStringValue: NSLocalizedString(@"Invalid Contents", @"")];
-    
-    soundPath = nil;
-		sound = nil;
-                
-    inspector = insp;
-    ws = [NSWorkspace sharedWorkspace];
-    
-    valid = YES;
-    
-    [self setContextHelp];
-	}
-	
+	    [indicator setIndeterminate: YES];
+	    [playBox addSubview: indicator]; 
+					
+	    editButt = [[NSButton alloc] initWithFrame: NSMakeRect(141, 10, 115, 25)];
+	    [editButt setButtonType: NSMomentaryLight];
+	    [editButt setImage: [NSImage imageNamed: @"common_ret.tiff"]];
+	    [editButt setImagePosition: NSImageRight];
+	    [editButt setTitle: NSLocalizedString(@"Edit", @"")];
+	    [editButt setTarget: self];
+	    [editButt setAction: @selector(editFile:)];	
+	    [editButt setEnabled: NO];		
+	    [self addSubview: editButt]; 
+	    RELEASE (editButt);
+
+	    errLabel = [[NSTextField alloc] init];	
+	    [errLabel setFrame: NSMakeRect(5, 162, [self bounds].size.width - 10, 25)];
+	    [errLabel setAlignment: NSCenterTextAlignment];
+	    [errLabel setFont: [NSFont systemFontOfSize: 18]];
+	    [errLabel setBackgroundColor: [NSColor windowBackgroundColor]];
+	    [errLabel setTextColor: [NSColor darkGrayColor]];	
+	    [errLabel setBezeled: NO];
+	    [errLabel setEditable: NO];
+	    [errLabel setSelectable: NO];
+	    [errLabel setStringValue: NSLocalizedString(@"Invalid Contents", @"")];
+
+	    soundPath = nil;
+	    sound = nil;
+
+	    inspector = insp;
+	    ws = [NSWorkspace sharedWorkspace];
+
+	    valid = YES;
+
+	    [self setContextHelp];
+	  }
+
 	return self;
 }
 
@@ -239,23 +240,12 @@
   DESTROY (snd);
 }
 
-- (void)displayLastPath:(BOOL)forced
-{
-  if (soundPath) {
-    if (forced) {
-      [self displayPath: soundPath];
-    } else {
-      [inspector contentsReadyAt: soundPath];
-    }
-  }
-}
-
 - (void)displayData:(NSData *)data 
              ofType:(NSString *)type
 {
 }
 
-- (NSString *)currentPath
+- (NSString *)path
 {
   return soundPath;
 }
@@ -274,8 +264,8 @@
 - (BOOL)canDisplayPath:(NSString *)path
 {
   NSDictionary *attributes;
-	NSString *defApp, *fileType, *extension;
-	NSArray *types;
+  NSString *defApp, *fileType, *extension;
+  NSArray *types;
 
   attributes = [[NSFileManager defaultManager] fileAttributesAtPath: path
                                                        traverseLink: YES];
@@ -284,11 +274,6 @@
   }		
 			
 	[ws getInfoForFile: path application: &defApp type: &fileType];
-	
-  if(([fileType isEqual: NSPlainFileType] == NO)
-                  && ([fileType isEqual: NSShellCommandFileType] == NO)) {
-    return NO;
-  }
 
 	extension = [path pathExtension];
 	types = [NSArray arrayWithObjects: @"aiff", @"wav", @"snd", @"au", nil];
