@@ -1,8 +1,10 @@
 /* Contents.m
  *  
- * Copyright (C) 2004-2016 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2024 Free Software Foundation, Inc.
+ *
+ * Author: Enrico Sersale
+ * Author: Riccardo Mottola <rm@gnu.org>
  *
- * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2004
  *
  * This file is part of the GNUstep GWorkspace application
@@ -19,7 +21,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #include <math.h>
@@ -63,68 +65,89 @@ static NSString *nibName = @"Contents";
 {
   self = [super init];
   
-  if (self) {
-    NSBundle *bundle;
-    NSEnumerator *enumerator;
-    NSString *imagepath;
-    NSString *bundlesDir;
-    NSArray *bnames;
-    id label;
-    unsigned i;
-    NSRect r;
+  if (self)
+    {
+      NSBundle *bundle;
+      NSEnumerator *enumerator;
+      NSString *imagepath;
+      NSString *bundlesDir;
+      NSArray *bnames;
+      id label;
+      unsigned i;
+      NSRect r;
 
-    if ([NSBundle loadNibNamed: nibName owner: self] == NO) {
-      NSLog(@"failed to load %@!", nibName);
-      [NSApp terminate: self];
-    } 
+      if ([NSBundle loadNibNamed: nibName owner: self] == NO)
+        {
+          NSLog(@"failed to load %@!", nibName);
+          [NSApp terminate: self];
+        }
 
-    RETAIN (mainBox);
-    RELEASE (win);
-    
-    inspector = insp;
-    [iconView setInspector: inspector];
-    viewers = [NSMutableArray new];
-    currentPath = nil;
+      RETAIN (mainBox);
+      RELEASE (win);
 
-    fm = [NSFileManager defaultManager];	
-    ws = [NSWorkspace sharedWorkspace];
+      inspector = insp;
+      [iconView setInspector: inspector];
+      viewers = [NSMutableArray new];
+      currentPath = nil;
 
-    bundle = [NSBundle bundleForClass: [inspector class]];
-    imagepath = [bundle pathForResource: @"Pboard" ofType: @"tiff"];
-    pboardImage = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-        
-    r = [[viewersBox contentView] bounds];
+      fm = [NSFileManager defaultManager];
+      ws = [NSWorkspace sharedWorkspace];
 
-    enumerator = [NSSearchPathForDirectoriesInDomains
-      (NSLibraryDirectory, NSAllDomainsMask, YES) objectEnumerator];
-    while ((bundlesDir = [enumerator nextObject]) != nil)
-      {
-	bundlesDir = [bundlesDir stringByAppendingPathComponent: @"Bundles"];
-	bnames = [fm directoryContentsAtPath: bundlesDir];
+      bundle = [NSBundle bundleForClass: [inspector class]];
+      imagepath = [bundle pathForResource: @"Pboard" ofType: @"tiff"];
+      pboardImage = [[NSImage alloc] initWithContentsOfFile: imagepath];
 
-	for (i = 0; i < [bnames count]; i++) {
-	  NSString *bname = [bnames objectAtIndex: i];
+      r = [[viewersBox contentView] bounds];
+
+      enumerator = [NSSearchPathForDirectoriesInDomains
+                     (NSLibraryDirectory, NSAllDomainsMask, YES) objectEnumerator];
+      while ((bundlesDir = [enumerator nextObject]) != nil)
+        {
+          bundlesDir = [bundlesDir stringByAppendingPathComponent: @"Bundles"];
+          bnames = [fm directoryContentsAtPath: bundlesDir];
+
+          for (i = 0; i < [bnames count]; i++)
+            {
+              NSString *bname = [bnames objectAtIndex: i];
 	
-	  if ([[bname pathExtension] isEqual: @"inspector"]) {
-	    NSString *bpath = [bundlesDir stringByAppendingPathComponent: bname];
-	    
-	    bundle = [NSBundle bundleWithPath: bpath]; 
-	  
-	    if (bundle) {
-	      Class principalClass = [bundle principalClass];
-	    
-	      if ([principalClass conformsToProtocol: @protocol(ContentViewersProtocol)]) {	
-                CREATE_AUTORELEASE_POOL (pool);
-		id vwr = [[principalClass alloc] initWithFrame: r inspector: self];
-	    
-		[viewers addObject: vwr];            
-		[vwr release];	
-		RELEASE (pool);		
-	      }
-	    }
+              if ([[bname pathExtension] isEqual: @"inspector"])
+                {
+                  NSString *bpath = [bundlesDir stringByAppendingPathComponent: bname];
+
+                  bundle = [NSBundle bundleWithPath: bpath];
+
+                  if (bundle)
+                    {
+                      Class principalClass = [bundle principalClass];
+
+                      if ([principalClass conformsToProtocol: @protocol(ContentViewersProtocol)])
+                        {
+                          CREATE_AUTORELEASE_POOL (pool);
+                          id vwr = [[principalClass alloc] initWithFrame: r inspector: self];
+
+                          [viewers addObject: vwr];
+                          [vwr release];
+                          RELEASE (pool);
+                        }
+                    }
+                }
+            }
+        }
+
+    // We reorter viewers and put the ImageViewer at the end, so that specialized viewers,
+    // e.g. PDF Viewer, can take precedence
+    // String comparison, so no class import is needed
+    for (i = 0; i < [viewers count]; i++)
+      {
+        id vwr = [viewers objectAtIndex: i];
+
+        if ([NSStringFromClass([vwr class]) isEqualToString:@"ImageViewer"])
+          {
+            [viewers removeObjectAtIndex: i];
+            [viewers addObject: vwr];
+            break;
           }
-	}
-    }
+      }
 
     textViewer = [[TextViewer alloc] initWithFrame: r forInspector: self];					
     genericView = [[GenericView alloc] initWithFrame: r];					
@@ -152,36 +175,41 @@ static NSString *nibName = @"Contents";
 
 - (void)activateForPaths:(NSArray *)paths
 {
-  if ([paths count] == 1) {
-    [self showContentsAt: [paths objectAtIndex: 0]];
+  if ([paths count] == 1)
+    {
+      [self showContentsAt: [paths objectAtIndex: 0]];
+    }
+  else
+    {
+      NSImage *icon = [[FSNodeRep sharedInstance] multipleSelectionIconOfSize: ICNSIZE];
+      NSString *items;
     
-  } else {
-    NSImage *icon = [[FSNodeRep sharedInstance] multipleSelectionIconOfSize: ICNSIZE];
-    NSString *items = NSLocalizedString(@"items", @"");
+      items = [NSString stringWithFormat: @"%lu %@",
+                        (unsigned long)[paths count],
+                        NSLocalizedString(@"Items", @"")];
+      [titleField setStringValue: items];  
+      [iconView setImage: icon];
     
-    items = [NSString stringWithFormat: @"%lu %@", (unsigned long)[paths count], items];
-		[titleField setStringValue: items];  
-    [iconView setImage: icon];
+      [viewersBox setContentView: noContsView];
+      currentViewer = noContsView;
     
-    [viewersBox setContentView: noContsView];
-    currentViewer = noContsView;
-    
-    if (currentPath) {
-      [inspector removeWatcherForPath: currentPath];
-      DESTROY (currentPath);
-    }    
+      if (currentPath) {
+        [inspector removeWatcherForPath: currentPath];
+        DESTROY (currentPath);
+      }    
 	
-	  [[inspector win] setTitle: [self winname]];    
-  }
+      [[inspector win] setTitle: [self winname]];
+    }
 }
 
 - (id)viewerForPath:(NSString *)path
 {
   NSInteger i;
   
-  if ((path == nil) || ([fm fileExistsAtPath: path] == NO)) {
-    return nil;
-  }
+  if ((path == nil) || ([fm fileExistsAtPath: path] == NO))
+    {
+      return nil;
+    }
     
   for (i = 0; i < [viewers count]; i++)
     {
@@ -197,7 +225,7 @@ static NSString *nibName = @"Contents";
 
 - (id)viewerForDataOfType:(NSString *)type
 {
-  NSInteger i;
+  NSUInteger i;
   
   for (i = 0; i < [viewers count]; i++)
     {
@@ -219,83 +247,99 @@ static NSString *nibName = @"Contents";
 {
   NSString *winName;
 
-  if (currentViewer) {
-    if ([currentViewer respondsToSelector: @selector(stopTasks)]) {
-      [currentViewer stopTasks];  
+  // No change in selection? leave current path
+  if (currentPath && [currentPath isEqual:path])
+    {
+      NSLog(@"trying to redisplay %@", path);
+      return;
     }
-  }   
-    	      
+
+  // we change content to new path or to nil
+  // stop current work (e.g. resizing)
+  if (currentViewer && [currentViewer respondsToSelector: @selector(stopTasks)])
+    {
+      [currentViewer stopTasks];
+    }
+
+  // stop watching the displayed content, since we change it
+  [inspector removeWatcherForPath: currentPath];
+  DESTROY (currentPath);
+
+  // Are we going to display the new path?
   if (path && [fm fileExistsAtPath: path])
     {
-      id viewer = [self viewerForPath: path];
+      id viewer;
 
-    if (currentPath && ([currentPath isEqual: path] == NO)) {
-      [inspector removeWatcherForPath: currentPath];
-      DESTROY (currentPath);
-    }
-        
-		if (viewer) {
-      currentViewer = viewer;
-      winName = [viewer winname];
-      [viewersBox setContentView: viewer];
+      viewer = [self viewerForPath: path];
+      if (viewer)
+	{
+	  currentViewer = viewer;
+	  winName = [viewer winname];
+	  [viewersBox setContentView: viewer];
     
-      if ([path isEqual: [viewer currentPath]]) {
-        [viewer displayLastPath: NO];
-      } else {
-			  [viewer displayPath: path];
-      }
-		} else {
-      FSNode *node = [FSNode nodeWithPath: path];
-      NSImage *icon = [[FSNodeRep sharedInstance] iconOfSize: ICNSIZE forNode: node];
-
-      [iconView setImage: icon];
-      [titleField setStringValue: [node name]];
-
-      if ([textViewer tryToDisplayPath: path]) {
-        [viewersBox setContentView: textViewer];
-        currentViewer = textViewer;
-			  winName = NSLocalizedString(@"Text Inspector", @"");      
-        if (currentPath == nil) {
-          ASSIGN (currentPath, path); 
-          [inspector addWatcherForPath: currentPath];
-        }
-        
-      } else {
-        [viewersBox setContentView: genericView];
-        currentViewer = genericView;
-        [genericView showInfoOfPath: path];
-			  winName = NSLocalizedString(@"Contents Inspector", @"");
-      }  
-    }
-		
-	} else {  
-    [iconView setImage: nil];
-    [titleField setStringValue: @""];
-    [viewersBox setContentView: noContsView];
-    currentViewer = noContsView;
-		winName = NSLocalizedString(@"Contents Inspector", @"");
-    
-    if (currentPath) {
-      [inspector removeWatcherForPath: currentPath];
-      DESTROY (currentPath);
-    }    
+	  [viewer displayPath: path];
 	}
+      else
+	{
+	  FSNode *node = [FSNode nodeWithPath: path];
+	  NSImage *icon = [[FSNodeRep sharedInstance] iconOfSize: ICNSIZE forNode: node];
+
+	  [iconView setImage: icon];
+	  [titleField setStringValue: [node name]];
+
+	  if ([textViewer tryToDisplayPath: path])
+	    {
+	      [viewersBox setContentView: textViewer];
+	      currentViewer = textViewer;
+	      winName = NSLocalizedString(@"Text Inspector", @"");
+	      if (currentPath == nil)
+		{
+		  ASSIGN (currentPath, path);
+		  [inspector addWatcherForPath: currentPath];
+		}
+	    }
+	  else
+	    {
+	      [viewersBox setContentView: genericView];
+	      currentViewer = genericView;
+	      [genericView showInfoOfPath: path];
+	      winName = NSLocalizedString(@"Contents Inspector", @"");
+	    }
+	}
+    }
+  else
+    {
+      [iconView setImage: nil];
+      [titleField setStringValue: @""];
+      [viewersBox setContentView: noContsView];
+      currentViewer = noContsView;
+      winName = NSLocalizedString(@"Contents Inspector", @"");
+
+      if (currentPath)
+	{
+	  [inspector removeWatcherForPath: currentPath];
+	  DESTROY (currentPath);
+	}
+    }
 	
-	[[inspector win] setTitle: winName];
+  [[inspector win] setTitle: winName];
 }
 
 - (void)contentsReadyAt:(NSString *)path
 {
-  FSNode *node = [FSNode nodeWithPath: path];
-  NSImage *icon = [[FSNodeRep sharedInstance] iconOfSize: ICNSIZE forNode: node];
+  FSNode *node;
+  NSImage *icon;
 
-  [iconView setImage: icon];
+  node = [FSNode nodeWithPath: path];
   [titleField setStringValue: [node name]];
+  icon = [[FSNodeRep sharedInstance] iconOfSize: ICNSIZE forNode: node];
+  [iconView setImage: icon];
 
-  if (currentPath == nil) {
-    ASSIGN (currentPath, path); 
-    [inspector addWatcherForPath: currentPath];
-  }
+  if (currentPath == nil)
+    {
+      ASSIGN (currentPath, path);
+      [inspector addWatcherForPath: currentPath];
+    }
 }
 
 - (BOOL)canDisplayDataOfType:(NSString *)type
@@ -394,9 +438,10 @@ static NSString *nibName = @"Contents";
 {
   self = [super initWithFrame: frameRect];
   
-  if (self) {
+  if (self)
+    {
     NSRect r = [self bounds];
-        
+
     r.origin.y += 45;
     r.size.height -= 45;
     scrollView = [[NSScrollView alloc] initWithFrame: r];
@@ -446,46 +491,49 @@ static NSString *nibName = @"Contents";
     ws = [NSWorkspace sharedWorkspace];
   }
 	
-	return self;
+  return self;
 }
 
 - (BOOL)tryToDisplayPath:(NSString *)path
 {
   NSFileManager *fm = [NSFileManager defaultManager];
   NSDictionary *attributes = [fm fileAttributesAtPath: path traverseLink: YES];
-  
+
   DESTROY (editPath);
   [editButt setEnabled: NO];	
 
-  if (attributes && ([attributes fileType] != NSFileTypeDirectory)) {
-	  NSString *app = nil, *type = nil;
-    
-    [ws getInfoForFile: path application: &app type: &type];
-    
-    if (type && ((type == NSPlainFileType) || (type == NSShellCommandFileType))) {
-      NSData *data = [self textContentsAtPath: path withAttributes: attributes];
+  if (attributes && ([attributes fileType] != NSFileTypeDirectory))
+    {
+      NSString *app = nil, *type = nil;
 
-      if (data) {
-        CREATE_AUTORELEASE_POOL (pool);
-        NSString *str = [[NSString alloc] initWithData: data
-                                  encoding: [NSString defaultCStringEncoding]];
-        NSAttributedString *attrstr = [[NSAttributedString alloc] initWithString: str];
+      [ws getInfoForFile: path application: &app type: &type];
 
-        [[textView textStorage] setAttributedString: attrstr];
-		    [[textView textStorage] addAttribute: NSFontAttributeName 
-                                       value: [NSFont systemFontOfSize: 8.0] 
-                                       range: NSMakeRange(0, [attrstr length])];
-        RELEASE (str);
-        RELEASE (attrstr);
-        [editButt setEnabled: YES];			
-        ASSIGN (editPath, path);
-        RELEASE (pool);
+      if (type && ((type == NSPlainFileType) || (type == NSShellCommandFileType)))
+	{
+	  NSData *data = [self textContentsAtPath: path withAttributes: attributes];
 
-        return YES;
-      }
+	  if (data)
+	    {
+	      CREATE_AUTORELEASE_POOL (pool);
+	      NSString *str = [[NSString alloc] initWithData: data
+						    encoding: [NSString defaultCStringEncoding]];
+	      NSAttributedString *attrstr = [[NSAttributedString alloc] initWithString: str];
+
+	      [[textView textStorage] setAttributedString: attrstr];
+	      [[textView textStorage] addAttribute: NSFontAttributeName
+					     value: [NSFont systemFontOfSize: 8.0]
+					     range: NSMakeRange(0, [attrstr length])];
+	      RELEASE (str);
+	      RELEASE (attrstr);
+	      [editButt setEnabled: YES];
+	      ASSIGN (editPath, path);
+	      RELEASE (pool);
+
+	      return YES;
+	    }
+	}
     }
-  }                                                     
-    
+
   return NO;
 }
 
@@ -594,38 +642,42 @@ static NSString *nibName = @"Contents";
 {
   [self showString: @""];
 
-  if (shComm && fileComm) {  
-    CREATE_AUTORELEASE_POOL (pool);
-    NSString *str;
-	  NSFileHandle *handle;  
-  
-    [nc removeObserver: self];
-    if (task && [task isRunning]) {
-		  [task terminate];
-	  }
-    DESTROY (task);		
+  if (shComm && fileComm)
+    {
+      CREATE_AUTORELEASE_POOL (pool);
+      NSString *str;
+      NSFileHandle *handle;
+
+      [nc removeObserver: self];
+          if (task && [task isRunning])
+            {
+              [task terminate];
+            }
+          DESTROY (task);		
     
-    task = [NSTask new]; 
-    [task setLaunchPath: shComm];
-    str = [NSString stringWithFormat: @"%@ -b \"%@\"", fileComm, path];
-    [task setArguments: [NSArray arrayWithObjects: @"-c", str, nil]];
-    ASSIGN (pipe, [NSPipe pipe]);
-    [task setStandardOutput: pipe];
+          task = [NSTask new]; 
+          [task setLaunchPath: shComm];
+          str = [NSString stringWithFormat: @"%@ -b \"%@\"", fileComm, path];
+          [task setArguments: [NSArray arrayWithObjects: @"-c", str, nil]];
+          ASSIGN (pipe, [NSPipe pipe]);
+          [task setStandardOutput: pipe];
 
-    handle = [pipe fileHandleForReading];
-    [nc addObserver: self
-    		   selector: @selector(dataFromTask:)
-    				   name: NSFileHandleReadToEndOfFileCompletionNotification
-    			   object: handle];
+          handle = [pipe fileHandleForReading];
+          [nc addObserver: self
+                 selector: @selector(dataFromTask:)
+                     name: NSFileHandleReadToEndOfFileCompletionNotification
+                   object: handle];
 
-    [handle readToEndOfFileInBackgroundAndNotify];    
+          [handle readToEndOfFileInBackgroundAndNotify];    
 
-    [task launch];   
+          [task launch];   
        
-    RELEASE (pool);   
-  } else {  
-    [self showString: NSLocalizedString(@"No Contents Inspector", @"")];
-  }        
+          RELEASE (pool);   
+  }
+  else
+    {  
+      [self showString: NSLocalizedString(@"No Contents Inspector", @"")];
+    }        
 }
 
 - (void)dataFromTask:(NSNotification *)notif
@@ -635,12 +687,15 @@ static NSString *nibName = @"Contents";
   NSData *data = [userInfo objectForKey: NSFileHandleNotificationDataItem];
   NSString *str;
   
-  if (data && [data length]) {
-    str = [[NSString alloc] initWithData: data 
-                                encoding: [NSString defaultCStringEncoding]];
-  } else {
-    str = [[NSString alloc] initWithString: NSLocalizedString(@"No Contents Inspector", @"")];
-  }
+  if (data && [data length])
+    {
+      str = [[NSString alloc] initWithData: data 
+                                  encoding: [NSString defaultCStringEncoding]];
+    }
+  else
+    {
+      str = [[NSString alloc] initWithString: NSLocalizedString(@"No Contents Inspector", @"")];
+    }
   
   [self showString: str];
   
